from setuptools import setup, find_packages

setup(
    name='rhains',
    version='0.1',
    description='a python framework for the web combining the \
        power of relational databases with Nosql databases',
    author='Hydromel Victor Doledji',
    packages=find_packages(),
    install_requires=[
    ]
)
